<?php

namespace EventPortal\Tests\Feature\Admin\Event;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Team\Models\Team;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Spatie\Snapshots\MatchesSnapshots;

class EventStoreTest extends TestCase
{
    use RefreshDatabase, MatchesSnapshots, SeedRolesAndPermissions;

    /** @test **/
    public function can_store_an_event(): void
    {
        $team = factory(Team::class)->create();
        $this
            ->actingAsSuperAdmin()
            ->followingRedirects()
            ->post(route('admin.event.store'), [
                'name' => 'New Event',
                'url' => 'New Url',
                'team_id' => $team->id,
            ])
            ->assertOk();
        $event = Event::first();
        $this->assertEquals(route('admin.event.show', $event), url()->current());

        $this->assertEquals('New Event', $event->name);
        $this->assertEquals('New Url', $event->url);
    }
}
